Exception: Hegel::AssumeFailed

Inherits:
Exception
  • Object
show all
Defined in:
lib/hegel/errors.rb,
sig/hegel.rbs

Overview

Raised for HEGEL_E_ASSUME (-2): an assume / reject precondition failed, so the current test case is invalid and must be discarded.

Descends from Exception for the same reason as StopTest above.